# Polars SQL

`polars-sql` is a sub-crate that provides a SQL transpiler for Polars. It can convert SQL queries to Polars logical plans.

## Usage

To use `polars-sql`, add it as a dependency to your Rust project's `Cargo.toml` file:

```toml
[dependencies]
polars-sql = "0.30.0"
```

You can then import the crate in your Rust code using:

```rust
use polars_sql::*;
```

## Features

Please refer to the parent `polars` crate for a comprehensive list of features.
